@@ -9,12 +9,56 @@ import sys
 from csvkit import CSVKitReader
 from csvkit.exceptions import ColumnIdentifierError
 
+def lazy_opener(fn):
+    def wrapped(self, *args, **kwargs):
+        self._lazy_open()
+        fn(*args, **kwargs)
+    return wrapped
+
+class LazyFile(object):
+    """
+    A proxy for a File object that delays opening it until
+    a read method is called.
+
+    Currently this implements only the minimum methods to be useful,
+    but it could easily be expanded.
+    """
+    def __init__(self, init, *args, **kwargs):
+        self.init = init
+        self.f = None
+        self._is_lazy_opened = False
+
+        self._lazy_args = args
+        self._lazy_kwargs = kwargs
+
+    def __getattr__(self, name):
+        if not self._is_lazy_opened:
+            self.f = self.init(*self._lazy_args, **self._lazy_kwargs)
+            self._is_lazy_opened = True
+
+        return getattr(self.f, name)
+
+    def __iter__(self):
+        return self
+
+    def close(self):
+        self.f.close()
+        self.f = None
+        self._is_lazy_opened = False
+
+    def next(self):
+        if not self._is_lazy_opened:
+            self.f = self.init(*self._lazy_args, **self._lazy_kwargs)
+            self._is_lazy_opened = True
+
+        return self.f.next()
+
 class CSVFileType(object):
     """
     An argument factory like argparse.FileType with compression support.
     """
 
-    def __init__(self, mode = "rb"):
+    def __init__(self, mode='rb'):
         """
         Initialize the factory.
         """
@@ -24,22 +68,22 @@ class CSVFileType(object):
         """
         Build a file-like object from the specified path.
         """
-        if path == "-":
-            if "r" in self._mode:
+        if path == '-':
+            if 'r' in self._mode:
                 return sys.stdin
-            elif "w" in self._mode:
+            elif 'w' in self._mode:
                 return sys.stdout
             else:
-                raise ValueError("invalid path \"-\" with mode {0}".format(self._mode))
+                raise ValueError('Invalid path "-" with mode {0}'.format(self._mode))
         else:
             (_, extension) = os.path.splitext(path)
 
-            if extension == ".gz":
-                return gzip.open(path, self._mode)
-            if extension == ".bz2":
-                return bz2.BZ2File(path, self._mode)
+            if extension == '.gz':
+                return LazyFile(gzip.open, path, self._mode)
+            if extension == '.bz2':
+                return LazyFile(bz2.BZ2File, path, self._mode)
             else:
-                return open(path, self._mode)
+                return LazyFile(open, path, self._mode)
 
 class CSVKitUtility(object):
     description = ''
@@ -201,7 +245,7 @@ class CSVKitUtility(object):
                 # Special case handling for Unicode errors, which behave very strangely
                 # when cast with unicode()
                 if t == UnicodeDecodeError:
-                    sys.stderr.write('%s\n' % value)
+                    sys.stderr.write('Your file is not "%s" encoded. Please specify the correct encoding with the -e flag. Use the -v flag to see the complete error.\n' % self.args.encoding)
                 else:
                     sys.stderr.write('%s\n' % unicode(value).encode('utf-8'))
 
@@ -254,47 +298,83 @@ def match_column_identifier(column_names, c, zero_based=False):
 
     return c
 
-def parse_column_identifiers(ids, column_names,zero_based=False):
+def parse_column_identifiers(ids, column_names, zero_based=False, excluded_columns=None):
     """
     Parse a comma-separated list of column indices AND/OR names into a list of integer indices.
     Ranges of integers can be specified with two integers separated by a '-' or ':' character. Ranges of 
     non-integers (e.g. column names) are not supported.
     Note: Column indices are 1-based. 
     """
-    # If not specified, return all columns 
-    if not ids:
-        return range(len(column_names))
-
     columns = []
 
-    for c in ids.split(','):
-        c = c.strip()
+    # If not specified, start with all columns 
+    if not ids:
+        columns = range(len(column_names))        
+
+    if columns and not excluded_columns:
+        return columns
+
+    if not columns:
+        for c in ids.split(','):
+            c = c.strip()
 
-        try:
-            columns.append(match_column_identifier(column_names, c, zero_based))
-        except ColumnIdentifierError:
-            if ':' in c:
-                a,b = c.split(':',1)
-            elif '-' in c:
-                a,b = c.split('-',1)
-            else:
-                raise
-            
             try:
-                if a:
-                    a = int(a)
+                columns.append(match_column_identifier(column_names, c, zero_based))
+            except ColumnIdentifierError:
+                if ':' in c:
+                    a,b = c.split(':',1)
+                elif '-' in c:
+                    a,b = c.split('-',1)
                 else:
-                    a = 1
-                if b:
-                    b = int(b) + 1
+                    raise
+                
+                try:
+                    if a:
+                        a = int(a)
+                    else:
+                        a = 1
+                    if b:
+                        b = int(b) + 1
+                    else:
+                        b = len(column_names)
+                        
+                except ValueError:
+                    raise ColumnIdentifierError("Invalid range %s. Ranges must be two integers separated by a - or : character.")
+                
+                for x in range(a,b):
+                    columns.append(match_column_identifier(column_names, x, zero_based))
+
+    excludes = []
+    
+    if excluded_columns:
+        for c in excluded_columns.split(','):
+            c = c.strip()
+
+            try:
+                excludes.append(match_column_identifier(column_names, c, zero_based))
+            except ColumnIdentifierError:
+                if ':' in c:
+                    a,b = c.split(':',1)
+                elif '-' in c:
+                    a,b = c.split('-',1)
                 else:
-                    b = len(column_names)
-                    
-            except ValueError:
-                raise ColumnIdentifierError("Invalid range %s. Ranges must be two integers separated by a - or : character.")
-            
-            for x in range(a,b):
-                columns.append(match_column_identifier(column_names, x, zero_based))
+                    raise
+                
+                try:
+                    if a:
+                        a = int(a)
+                    else:
+                        a = 1
+                    if b:
+                        b = int(b) + 1
+                    else:
+                        b = len(column_names)
+                        
+                except ValueError:
+                    raise ColumnIdentifierError("Invalid range %s. Ranges must be two integers separated by a - or : character.")
+                
+                for x in range(a,b):
+                    excludes.append(match_column_identifier(column_names, x, zero_based))
 
-    return columns
+    return [c for c in columns if c not in excludes]
 
