@@ -18,7 +18,7 @@ class Column(list):
     """
     A normalized data column and inferred annotations (nullable, etc.).
     """
-    def __init__(self, order, name, l, normal_type=InvalidType):
+    def __init__(self, order, name, l, normal_type=InvalidType, blanks_as_nulls=True):
         """
         Construct a column from a sequence of values.
         
@@ -28,7 +28,7 @@ class Column(list):
             t = normal_type
             data = l
         else:
-            t, data = typeinference.normalize_column_type(l)
+            t, data = typeinference.normalize_column_type(l, blanks_as_nulls=blanks_as_nulls)
         
         list.__init__(self, data)
         self.order = order
@@ -174,7 +174,7 @@ class Table(list):
         return row_data
 
     @classmethod
-    def from_csv(cls, f, name='from_csv_table', snifflimit=None, column_ids=None, **kwargs):
+    def from_csv(cls, f, name='from_csv_table', snifflimit=None, column_ids=None, blanks_as_nulls=True, zero_based=False, **kwargs):
         """
         Creates a new Table from a file-like object containing CSV data.
 
@@ -200,7 +200,7 @@ class Table(list):
         headers = reader.next()
         
         if column_ids:
-            column_ids = parse_column_identifiers(column_ids, headers)
+            column_ids = parse_column_identifiers(column_ids, headers, zero_based)
             headers = [headers[c] for c in column_ids]
         else:
             column_ids = range(len(headers))
@@ -218,7 +218,7 @@ class Table(list):
         columns = []
 
         for i, c in enumerate(data_columns):
-            columns.append(Column(column_ids[i], headers[i], c))
+            columns.append(Column(column_ids[i], headers[i], c, blanks_as_nulls=blanks_as_nulls))
 
         return Table(columns, name=name)
 
