@@ -6,10 +6,13 @@ This module contains unicode aware replacements for :func:`csv.reader` and :func
 
 import codecs
 import csv
+import fnmatch
 from cStringIO import StringIO
 
 from csvkit.exceptions import FieldSizeLimitError
 
+EIGHT_BIT_ENCODINGS = ['utf-8', 'u8', 'utf', 'utf8', 'latin-1', 'iso-8859-1', 'iso8859-1', '8859', 'cp819', 'latin', 'latin1', 'l1']
+
 class UTF8Recoder(object):
     """
     Iterator that reads an encoded stream and reencodes the input to UTF-8.
@@ -40,7 +43,7 @@ class UnicodeCSVReader(object):
             row = self.reader.next()
         except csv.Error, e:
             # Terrible way to test for this exception, but there is no subclass
-            if 'field larger than field limit' in str(e):
+            if fnmatch.fnmatch(str(e), 'field large[rt] than field limit *'):
                 raise FieldSizeLimitError(csv.field_size_limit())
             else:
                 raise e
@@ -57,25 +60,37 @@ class UnicodeCSVReader(object):
 class UnicodeCSVWriter(object):
     """
     A CSV writer which will write rows to a file in the specified encoding.
+
+    NB: Optimized so that eight-bit encodings skip re-encoding. See:
+        https://github.com/onyxfish/csvkit/issues/175
     """
     def __init__(self, f, encoding='utf-8', **kwargs):
-        # Redirect output to a queue
-        self.queue = StringIO()
-        self.writer = csv.writer(self.queue, **kwargs)
-        self.stream = f
-        self.encoder = codecs.getincrementalencoder(encoding)()
+        self.encoding = encoding
+        self._eight_bit = (self.encoding.lower().replace('_', '-') in EIGHT_BIT_ENCODINGS)
+
+        if self._eight_bit:
+            self.writer = csv.writer(f, **kwargs)
+        else:
+            # Redirect output to a queue for reencoding
+            self.queue = StringIO()
+            self.writer = csv.writer(self.queue, **kwargs)
+            self.stream = f
+            self.encoder = codecs.getincrementalencoder(encoding)()
 
     def writerow(self, row):
-        self.writer.writerow([unicode(s if s != None else '').encode('utf-8') for s in row])
-        # Fetch UTF-8 output from the queue ...
-        data = self.queue.getvalue()
-        data = data.decode('utf-8')
-        # ... and reencode it into the target encoding
-        data = self.encoder.encode(data)
-        # write to the target stream
-        self.stream.write(data)
-        # empty queue
-        self.queue.truncate(0)
+        if self._eight_bit:
+            self.writer.writerow([unicode(s if s != None else '').encode(self.encoding) for s in row])
+        else:
+            self.writer.writerow([unicode(s if s != None else '').encode('utf-8') for s in row])
+            # Fetch UTF-8 output from the queue...
+            data = self.queue.getvalue()
+            data = data.decode('utf-8')
+            # ...and reencode it into the target encoding
+            data = self.encoder.encode(data)
+            # write to the file 
+            self.stream.write(data)
+            # empty the queue
+            self.queue.truncate(0)
 
     def writerows(self, rows):
         for row in rows:
@@ -87,8 +102,14 @@ class UnicodeCSVDictReader(csv.DictReader):
     of :func:`csv.reader`.
     """
     def __init__(self, f, fieldnames=None, restkey=None, restval=None, *args, **kwargs):
+        reader = UnicodeCSVReader(f, *args, **kwargs)
+
+        if 'encoding' in kwargs:
+            kwargs.pop('encoding')
+
         csv.DictReader.__init__(self, f, fieldnames, restkey, restval, *args, **kwargs)
-        self.reader = UnicodeCSVReader(f, *args, **kwargs)
+
+        self.reader = reader 
 
 class UnicodeCSVDictWriter(csv.DictWriter):
     """
