@@ -57,10 +57,12 @@ class CSVGrep(CSVKitUtility):
         filter_reader = FilteringCSVReader(rows, header=False, patterns=patterns, inverse=self.args.inverse)
 
         for i, row in enumerate(filter_reader):
-            self.input_line_number = i + 1
             output.writerow(row)
-                
-if __name__ == "__main__":
+
+def launch_new_instance():
     utility = CSVGrep()
     utility.main()
+    
+if __name__ == "__main__":
+    launch_new_instance()
 
