@@ -44,6 +44,7 @@ class CSVJoin(CSVKitUtility):
 
         for f in self.args.files:
             tables.append(list(CSVKitReader(f, **self.reader_kwargs)))
+            f.close()
 
         join_column_ids = []
         
@@ -98,7 +99,12 @@ class CSVJoin(CSVKitUtility):
         Parse a list of join columns.
         """
         return map(str.strip, join_string.split(','))
-    
-if __name__ == '__main__':
+
+
+def launch_new_instance():
     utility = CSVJoin()
     utility.main()
+    
+if __name__ == "__main__":
+    launch_new_instance()
+
