@@ -24,13 +24,13 @@ class CSVLook(CSVKitUtility):
                 except IndexError:
                     widths.append(len(v))
 
-        # Width of the fields, plus space between, plus fore and aft dividers 
-        divider = '-' * (sum(widths) + (3 * len(widths)) + 3)
+        # Dashes span each width with '+' character at intersection of
+        # horizontal and vertical dividers.
+        divider = '|--' + '-+-'.join('-'* w for w in widths) + '--|'
 
         self.output_file.write('%s\n' % divider)
 
         for i, row in enumerate(rows):
-            self.input_line_number = i + 1
             output = []
 
             for j, d in enumerate(row):
@@ -43,6 +43,10 @@ class CSVLook(CSVKitUtility):
             if i == 0 or i == len(rows) - 1:
                 self.output_file.write('%s\n' % divider)
 
-if __name__ == '__main__':
+def launch_new_instance():
     utility = CSVLook()
     utility.main()
+    
+if __name__ == "__main__":
+    launch_new_instance()
+
