@@ -30,11 +30,16 @@ class CSVSQL(CSVKitUtility):
             help='Skip creating a table. Only valid when --insert is specified.')
         self.argparser.add_argument('--blanks', dest='blanks', action='store_true',
             help='Do not coerce empty strings to NULL values.')
+        self.argparser.add_argument('--no-infer', dest='no_infer',
+            help='A comma separated list of column indices or names to skip type inference. Specified columns will be treated as strings.')
 
     def main(self):
         # Ensure we're handling a list, even if it's just one file
         if not isinstance(self.args.files, list):
             self.args.files = [self.args.files]
+        else:
+            if self.args.table_name:
+                self.argparser.error('The --table argument is only allowed when specifying a single file.')
 
         for f in self.args.files:
             if self.args.table_name:
@@ -56,6 +61,8 @@ class CSVSQL(CSVKitUtility):
 
             csv_table = table.Table.from_csv(f, name=table_name, snifflimit=self.args.snifflimit, blanks_as_nulls=(not self.args.blanks), **self.reader_kwargs)
 
+            f.close()
+
             # Direct connections to database
             if self.args.connection_string:
                 try:
@@ -84,7 +91,11 @@ class CSVSQL(CSVKitUtility):
                 sql_table = sql.make_table(csv_table, table_name, self.args.no_constraints)
                 self.output_file.write((u'%s\n' % sql.make_create_table_statement(sql_table, dialect=self.args.dialect)).encode('utf-8'))
 
-if __name__ == '__main__':
+
+def launch_new_instance():
     utility = CSVSQL()
     utility.main()
+    
+if __name__ == "__main__":
+    launch_new_instance()
 
